import random

# Шифровка
def ENS(text):

    #Символы
    sSym = '&$%@=¿!qwertyuiopasdfghjklzxcvbnm1234567890'
    
    tx = ''

    if text != '':

        for i in text:
        
            # Если символ цифра
            if i.isdigit() == True:
                eSym = random.choice(sSym)
                tx += f'nS+{ord(i)}{eSym}S%$'
        
            # Если символ буква
            elif i.isdigit() == False and i != ' ':
                Lsym = random.randint(0,1)
                if Lsym == 0:
                    Lsym = 'l'
                elif Lsym == 1:
                    Lsym = 'L'
                Sym2 = random.choice(sSym)
                Sym3 = random.choice(sSym)
            
                tx += f'{Lsym}{Sym2}={Sym3}{ord(i)}S%$'
        
            # Если символ пробел
            elif i.isdigit() == False and i == ' ':
                Ssym = random.randint(0,1)
                if Ssym == 0:
                    Ssym = 's'
                elif Ssym == 1:
                    Ssym = 'S'
                Sym2 = random.choice(sSym)
                Sym3 = random.choice(sSym)
                    
                tx += f'{Ssym}{Sym2}={Sym3}{ord(i)}S%$'
    else:
        tx = 'LNt'
    
    if tx != 'LNt':
        tx = tx[0:-3]
    return tx

# Расшифровка
def DEC(text):

    #Символы
    sSym = '&$%@=¿!qwertyuiopasdfghjklzxcvbnm1234567890'

    tx = ''
    
    get = text.split('S%$')
    
    if text != 'LNt':

        for i in get:
        
            # Если символ цифра
            if i[0:3] == 'nS+' and i[-1] in sSym:
                tx += f'{chr(int(i[3:-1]))}'
                
            # Если символ буква
            elif i[0].lower() == 'l' and i[2] == '=' and i[3] in sSym and i[1] in sSym:
                tx += f'{chr(int(i[4:-1] + i[-1]))}'
        
            # Если символ пробел
            elif i[0].lower() == 's' and i[2] == '=' and i[3] in sSym and i[1] in sSym:
                tx += f'{chr(int(i[4:-1] + i[-1]))}'
    else:
        tx = ''
    
    return tx


#!/usr/bin/python

from setuptools import setup, Extension

Version = '1.0.2'

longDesk = '''
ENG:

enscrypt(text) -> encrypt text

decrypt(text) -> decrypt the text

Encryption example:
    text = encrypt('this is text')

    print(text)

Conclusion:
   le=g116S%$L2=0104S%$Ll=e105S%$l2=¿115S%$se=132S%$Lz=6105S%$ly=q115S%$Sx=132S%$Ls=@116S%$L%=h101S%$Lu=9120S%$Lm=%116

decryption example:
    text = decrypt('le=g116S%$L2=0104S%$Ll=e105S%$l2=¿115S%$se=132S%$Lz=6105S%$ly=q115S%$Sx=132S%$Ls=@116S%$L%=h101S%$Lu=9120S%$Lm=%116')

    print(text)

Conclusion:
    this is text

RU:

enscrypt(text) -> шифрует текст

decrypt(text) -> расшифровает текст

Пример enscryption:
    text = enscrypt('this is text')

    print(text)

Вывод:
    le=g116S%$L2=0104S%$Ll=e105S%$l2=¿115S%$se=132S%$Lz=6105S%$ly=q115S%$Sx=132S%$Ls=@116S%$L%=h101S%$Lu=9120S%$Lm=%116

Пример decryption:
    text = decrypt('le=g116S%$L2=0104S%$Ll=e105S%$l2=¿115S%$se=132S%$Lz=6105S%$ly=q115S%$Sx=132S%$Ls=@116S%$L%=h101S%$Lu=9120S%$Lm=%116')

    print(text)

Вывод:
    this is text

'''

setup(
    name='encoderPy',
    version=Version,

    author='AlmazCode',
    author_email='diamondplay43@gmail.com',

    description='Simple encoder & text decryptor',
    long_description=longDesk,

    license='Apache License, Version 2.0, see LICENSE file',

    packages=['encoderPy'],

    classifiers=['License :: OSI Approved :: Apache Software License',
                'Operating System :: OS Independent',
                'Intended Audience :: End Users/Desktop',
                'Intended Audience :: Developers',
                'Programming Language :: Python',
                'Programming Language :: Python :: 3',
                'Programming Language :: Python :: 3.6',
                'Programming Language :: Python :: 3.7',
                'Programming Language :: Python :: 3.8',
                'Programming Language :: Python :: 3.9',
                'Programming Language :: Python :: 3.10',
                'Programming Language :: Python :: Implementation :: PyPy',
                'Programming Language :: Python :: Implementation :: CPython'
                ]
)